@@ -742,4 +742,29 @@ bb_zoom <- function(bb, ...) {
   
   .bb_opt(bb, "zoom", ...)
   
-}
\ No newline at end of file
+}
+
+
+
+
+
+
+
+#' Bubble property for a Billboard.js chart
+#'
+#' @param bb A \code{billboard} \code{htmlwidget} object.
+#' @param ... See \url{https://naver.github.io/billboard.js/release/latest/doc/Options.html#.bubble}
+#'
+#' @return A \code{billboard} \code{htmlwidget} object.
+#' @export
+#'
+#' @examples
+#' #
+bb_bubble <- function(bb, ...) {
+  
+  .bb_opt(bb, "bubble", ...)
+  
+}
+
+
+
